@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from mypy import api
 from prospector.message import Location, Message
 from prospector.tools import ToolBase
@@ -56,6 +55,7 @@ class MypyTool(ToolBase):
         python_2_mode = options.get("python-2-mode", False)
         python_version = options.get("python-version", None)
         strict_optional = options.get("strict-optional", False)
+        namespace_packages = options.get("namespace-packages", False)
 
         self.options.append("--follow-imports=%s" % follow_imports)
 
@@ -80,6 +80,9 @@ class MypyTool(ToolBase):
         if strict_optional:
             self.options.append("--strict-optional")
 
+        if namespace_packages:
+            self.options.append("--namespace-packages")
+
         for list_option in MYPY_OPTIONS:
             for entry in options.get(list_option, []):
                 self.options.append("--%s-%s" % (list_option, entry))
